@@ -922,8 +922,8 @@ class GetListPage(TreePage):
         iters = []
         for path in paths:
             iters.append(self.model.get_iter(path))
-        for iter in iters:
-            self.model.remove(iter)
+        for it in iters:
+            self.model.remove(it)
         self.validate()
 
     def execute(self, prompt):
@@ -1029,7 +1029,25 @@ class MenuPage(Page):
         desc_column.set_cell_data_func(rend, self.on_cell_func)
         self.view.append_column(desc_column)
 
-        default_iter = None
+        if multiple:
+            if default is None:
+                default = []
+            elif isinstance(default, str):
+                default = [default]
+
+        def enable_option(option):
+            nonlocal default
+            if multiple:
+                return option in default
+            else:
+                if default is None:
+                    return False
+                elif option == default:
+                    default = None
+                    return True
+                else:
+                    return False
+
         # here below, 'text' is the value of the description of the item, but
         # written all on a single line, it will be wrapped by the list settings
         if isinstance(options, dict):
@@ -1037,24 +1055,18 @@ class MenuPage(Page):
                 for option in order:
                     if option in options:
                         text = ' '.join(options[option].split())
-                        iter = self.model.append([False, highlight(option), text])
-                        if option == default:
-                            default_iter = iter
+                        on = enable_option(option)
+                        self.model.append([on, highlight(option), text])
             for option, desc in options.items():
                 if not order or option not in order:
                     text = ' '.join(desc.split())
-                    iter = self.model.append([False, highlight(option), text])
-                    if option == default:
-                        default_iter = iter
+                    on = enable_option(option)
+                    self.model.append([on, highlight(option), text])
         else:
             for row in options:
                 text = ' '.join(row[1].split())
-                iter = self.model.append([False, highlight(row[0]), text])
-                if row[0] == default:
-                    default_iter = iter
-
-        if default_iter:
-            self.model.set_value(default_iter, 0, True)
+                on = enable_option(row[0])
+                self.model.append([on, highlight(row[0]), text])
 
         self.validate()
 
@@ -1148,7 +1160,7 @@ class HandleBTSQueryPage(TreePage):
                     buglist = sorted(bugs, key=lambda b: b.bug_num, reverse=latest_first)
                     report.append((category, list(map(Bug, buglist))))
 
-                return(report, sectitle), {}
+                return (report, sectitle), {}
 
         except NoPackage:
             raise NoPackage
@@ -1230,14 +1242,14 @@ class HandleBTSQueryPage(TreePage):
         # The value returned to reportbug doesn't depend by a selection, but by the dialog of a bug
         return None
 
-    def match_filter(self, iter):
+    def match_filter(self, itr):
         _assert_context(ui_context)
         # Flatten the columns into a single string
         text = ""
         for col in range(len(self.columns)):
-            value = self.model.get_value(iter, col)
+            value = self.model.get_value(itr, col)
             if value:
-                text += self.model.get_value(iter, col) + " "
+                text += self.model.get_value(itr, col) + " "
 
         text = text.lower()
         # Tokens shouldn't be adjacent by default
@@ -1246,12 +1258,12 @@ class HandleBTSQueryPage(TreePage):
                 return True
         return False
 
-    def filter_visible_func(self, model, iter, user_data=None):
+    def filter_visible_func(self, model, itr, user_data=None):
         _assert_context(ui_context)
-        matches = self.match_filter(iter)
-        if not self.model.iter_parent(iter) and not matches:
+        matches = self.match_filter(itr)
+        if not self.model.iter_parent(itr) and not matches:
             # If no children are visible, hide it
-            it = model.iter_children(iter)
+            it = model.iter_children(itr)
             while it:
                 if self.match_filter(it):
                     return True
@@ -1268,9 +1280,9 @@ class HandleBTSQueryPage(TreePage):
         for category in buglist:
             row = [None] * len(self.columns)
             row[3] = category[0]
-            iter = self.model.append(None, row)
+            itr = self.model.append(None, row)
             for bug in category[1]:
-                self.model.append(iter, list(map(str, bug)))
+                self.model.append(itr, list(map(str, bug)))
 
         self.selection.set_mode(Gtk.SelectionMode.MULTIPLE)
 
@@ -1353,7 +1365,7 @@ class LongMessagePage(Page):
         # no need to wrap the message, it will be wrapped at display-time
         # but separate all paragraphs by an empty line
         message = '\n\n'.join(par for par in message.splitlines() if par)
-        if('nnnnnn' in message):
+        if 'nnnnnn' in message:
             message = 'Thank you for your report.\n\n' + message
         GLib.idle_add(self.label.set_text, message)
 
@@ -1447,7 +1459,7 @@ class EditorPage(Page):
 
         self.report.set_subject(subject)
         message = self.report.create_message(info)
-        return(message, message != self.message)
+        return (message, message != self.message)
 
     def handle_first_info(self):
         _assert_context(ui_context)
