@@ -1,7 +1,7 @@
 # Text user interface for reportbug
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2001-08 Chris Lawrence
-#   Copyright (C) 2008-2022 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2023 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -318,14 +318,21 @@ def get_filename(prompt, title=None, force_prompt=False, default=''):
                       default=default, completer=FilenameCompleter)
 
 
-def select_multiple(par, options, prompt, title=None, order=None, extras=None):
-    return menu(par, options, prompt, title=title, order=order, extras=extras,
-                multiple=True, empty_ok=False)
+def select_multiple(par, options, prompt, default=None, title=None,
+                    order=None, extras=None):
+    return menu(par, options, prompt, default=default, title=title,
+                order=order, extras=extras, multiple=True, empty_ok=False)
 
 
 def menu(par, options, prompt, default=None, title=None, any_ok=False,
          order=None, extras=None, multiple=False, empty_ok=False):
-    selected = {}
+    if multiple:
+        if default is None:
+            default = []
+        elif isinstance(default, str):
+            default = [default]
+
+        selected = {key: 1 for key in default}
 
     if not extras:
         extras = []
@@ -359,7 +366,10 @@ def menu(par, options, prompt, default=None, title=None, any_ok=False,
 
     if multiple:
         options.append(('none', ''))
-        default = 'none'
+        if len(selected):
+            default = 'done'
+        else:
+            default = 'none'
         extras += ['done']
 
     allowed = [x[0] for x in options]
@@ -381,6 +391,8 @@ def menu(par, options, prompt, default=None, title=None, any_ok=False,
 
     if multiple:
         prompt += '(one at a time) '
+        if selected:
+            ewrite('- selected: %s\n' % ', '.join(list(selected.keys())))
 
     while 1:
         if default:
@@ -598,6 +610,11 @@ def handle_bts_query(package, bts, timeout, mirrors=None, http_proxy="",
         else:
             ewrite('%d bug reports found:\n\n', count)
 
+        # only pass a single package name to browse_bugs
+        if isinstance(package, list):
+            package = [p[4:] for p in package if p.startswith("src:")][0]
+            source = True
+
         return browse_bugs(hierarchy, count, bugs, bts, queryonly,
                            mirrors, http_proxy, timeout, screen, title,
                            package, source, mbox_reader_cmd)
